==> pffloader-1.14.4-1.15x-0.3.0-sources.jar: com/ptk671/pffloader/api/item/PffItemSettings.java <==
package com.ptk671.pffloader.api.item;

import net.fabricmc.fabric.api.item.v1.FabricItemSettings;
import net.minecraft.class_1761;
import net.minecraft.class_1792;
import net.minecraft.class_1814;

public class PffItemSettings {
    private FabricItemSettings settings = new FabricItemSettings();

    public PffItemSettings maxCount(int maxcount)
    {
        settings.method_7889(maxcount);
        return this;
    }

    public PffItemSettings maxDamageIfAbsent(int maxDamage)
    {
        settings.method_7898(maxDamage);
        return this;
    }

    public PffItemSettings maxDamage(int maxDamage)
    {
        settings.method_7895(maxDamage);
        return this;
    }
    public PffItemSettings recipeRemainder(class_1792 recipeRemainder)
    {
        settings.method_7896(recipeRemainder);
        return this;
    }

    //>=1.19.3
    public PffItemSettings group(PffItem pffItem, class_1761 itemGroup)
    {
        settings.method_7892(itemGroup);
        return this;
    }

    //=>1.19.2
    public PffItemSettings group(class_1761 itemGroup)
    {
        settings.method_7892(itemGroup);
        return this;
    }

    public PffItemSettings rarity(class_1814 rarity)
    {
        settings.method_7894(rarity);
        return this;
    }

    public PffItemSettings fireproof()
    {
        return this;
    }
    public PffItemSettings food(PffFoodComponent pffFoodComponent)
    {
        settings.method_19265(pffFoodComponent.build());
        return this;
    }

    public FabricItemSettings build() {
        return settings;
    }

}

==> pffloader-1.17x-1.19.2-0.3.0-sources.jar: com/ptk671/pffloader/api/item/PffItemSettings.java <==
package com.ptk671.pffloader.api.item;

import net.fabricmc.fabric.api.item.v1.FabricItemSettings;
import net.minecraft.class_1761;
import net.minecraft.class_1792;
import net.minecraft.class_1814;

public class PffItemSettings {
    private FabricItemSettings settings = new FabricItemSettings();

    public PffItemSettings maxCount(int maxcount)
    {
        settings.method_7889(maxcount);
        return this;
    }

    public PffItemSettings maxDamageIfAbsent(int maxDamage)
    {
        settings.method_7898(maxDamage);
        return this;
    }

    public PffItemSettings maxDamage(int maxDamage)
    {
        settings.method_7895(maxDamage);
        return this;
    }
    public PffItemSettings recipeRemainder(class_1792 recipeRemainder)
    {
        settings.method_7896(recipeRemainder);
        return this;
    }

    //>=1.19.3
    public PffItemSettings group(PffItem pffItem, class_1761 itemGroup)
    {
        settings.method_7892(itemGroup);
        return this;
    }

    //=>1.19.2
    public PffItemSettings group(class_1761 itemGroup)
    {
        settings.method_7892(itemGroup);
        return this;
    }

    public PffItemSettings rarity(class_1814 rarity)
    {
        settings.method_7894(rarity);
        return this;
    }

    public PffItemSettings fireproof()
    {
        settings.method_24359();
        return this;
    }

    public PffItemSettings food(PffFoodComponent foodComponent)
    {
        settings.method_19265(foodComponent.build());
        return this;
    }

    public FabricItemSettings build() {
        return settings;
    }

}
